@@ -7,6 +7,6 @@ use Java;
 $java = new Java;
 $global_hash={'name'=>"Mr. President"};
 my($perlobj)=$java->get_callback_object();
-my($obj)=$java->create_object("perljava",$perlobj);
+my($obj)=$java->create_object("com.zzo.javaserver.perljava",$perlobj);
 print($obj->doSomeJavaCode()->get_value());
 
